<template>
  <div id="main">
    <basic-container>
      <v-chart id="chart" :auto-resize="true" :options="chartOptions"></v-chart>
    </basic-container>
  </div>
</template>

<script>
import 'echarts'
import 'echarts/lib/chart/line'
import 'echarts/lib/component/tooltip'
import 'echarts/lib/component/title'
import 'echarts/lib/component/legend'

export default {
  name: "lineChart",
  props: {
    lineData: {
      type: Array,
      default: []
    },
    chartName: {
      type: String,
      default: ""
    }
  },
  watch: {
    lineData: {
      immediate: true,
      handler(newval, oldval) {
        if (newval) {
          const series = newval.map((data, index) => ({
            name: index === 0 ? "总量" : "新增",
            type: "line",
            smooth: true,
            stack: "Total",
            label: {
              show: true,
              position: "top"
            },
            data: data.map(value => ({value}))
          }));

          this.chartOptions.series = series;
        }
      }
    },
    chartName:{
      handler(newval,oldval){
        if(newval){
          this.chartOptions.title.text = newval + "数据统计"
        }
      },
      immediate:true,
      deep:true
    }
  },
  data() {
    return {
      chartOptions: {
        color: ['#2eadd6', '#FFA500'],
        title: {
          text: ''
        },
        tooltip: {
          trigger: 'axis'
        },
        legend: {
          data: ['总量', '新增']
        },
        xAxis: {
          boundaryGap: true,
          type: 'category',
          data: ['1月', '2月', '3月', '4月', '5月', '6月', '7月', '8月', '9月', '10月', '11月', '12月']
        },
        yAxis: {
          type: 'value'
        },
        series: []
      }
    };
  },
  created() {
  }
};
</script>

<style lang="scss" scoped>
#chart {
  width: 100%;
  height: 400px;
}
</style>
